@@ -1,26 +1,10 @@
 /*
   This file is part of libkdepim.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "kcheckcombobox.h"
@@ -39,15 +23,11 @@ using namespace KPIM;
 namespace KPIM {
 class Q_DECL_HIDDEN KCheckComboBox::Private
 {
-    KCheckComboBox *q = nullptr;
 
 public:
     Private(KCheckComboBox *qq)
-        : q(qq)
-        , mSeparator(QLatin1Char(','))
-        , mSqueezeText(false)
-        , mIgnoreHide(false)
-        , mAlwaysShowDefaultText(false)
+        : mSeparator(QLatin1Char(','))
+        , q(qq)
     {
     }
 
@@ -59,16 +39,18 @@ public:
 public:
     QString mSeparator;
     QString mDefaultText;
-    bool mSqueezeText;
-    bool mIgnoreHide;
-    bool mAlwaysShowDefaultText;
+    bool mSqueezeText = false;
+    bool mIgnoreHide = false;
+    bool mAlwaysShowDefaultText = false;
+private:
+    KCheckComboBox *const q;
 };
 }
 
 void KCheckComboBox::Private::makeInsertedItemsCheckable(const QModelIndex &parent, int start, int end)
 {
     Q_UNUSED(parent);
-    QStandardItemModel *model = qobject_cast<QStandardItemModel *>(q->model());
+    auto *model = qobject_cast<QStandardItemModel *>(q->model());
     if (model) {
         for (int r = start; r <= end; ++r) {
             QStandardItem *item = model->item(r, 0);
@@ -124,7 +106,7 @@ void KCheckComboBox::Private::toggleCheckState()
         const QModelIndex index = q->view()->currentIndex();
         QVariant value = index.data(Qt::CheckStateRole);
         if (value.isValid()) {
-            Qt::CheckState state = static_cast<Qt::CheckState>(value.toInt());
+            auto state = static_cast<Qt::CheckState>(value.toInt());
             q->model()->setData(index, state == Qt::Unchecked ? Qt::Checked : Qt::Unchecked,
                                 Qt::CheckStateRole);
         }
@@ -247,7 +229,7 @@ bool KCheckComboBox::itemEnabled(int index)
 {
     Q_ASSERT(index >= 0 && index <= count());
 
-    QStandardItemModel *itemModel = qobject_cast<QStandardItemModel *>(model());
+    auto *itemModel = qobject_cast<QStandardItemModel *>(model());
     Q_ASSERT(itemModel);
 
     QStandardItem *item = itemModel->item(index, 0);
@@ -258,7 +240,7 @@ void KCheckComboBox::setItemEnabled(int index, bool enabled)
 {
     Q_ASSERT(index >= 0 && index <= count());
 
-    QStandardItemModel *itemModel = qobject_cast<QStandardItemModel *>(model());
+    auto *itemModel = qobject_cast<QStandardItemModel *>(model());
     Q_ASSERT(itemModel);
 
     QStandardItem *item = itemModel->item(index, 0);
